@@ -1,10 +1,11 @@
-from typing import List, Dict, Tuple
+from typing import Dict, List, Tuple
 
 from credsweeper.credentials.candidate import Candidate
 from credsweeper.credentials.candidate_key import CandidateKey
 
 
 class CandidateGroupGenerator:
+
     def __init__(self) -> None:
         self.grouped_candidates: Dict[CandidateKey, List[Candidate]] = {}
 
