@@ -16,11 +16,15 @@ class StringContentProvider(ContentProvider):
     def __init__(
             self,  #
             lines: List[str],  #
+            line_numbers: Optional[List[int]] = None,  #
             file_path: Optional[str] = None,  #
             file_type: Optional[str] = None,  #
             info: Optional[str] = None) -> None:
         super().__init__(file_path=file_path, file_type=file_type, info=info)
         self.lines = lines
+        # fill line numbers only when amounts are equal
+        self.line_numbers = line_numbers if line_numbers and len(self.lines) == len(line_numbers) \
+            else (list(range(1, 1 + len(self.lines))) if self.lines else [])
 
     def get_analysis_target(self) -> List[AnalysisTarget]:
         """Return lines to scan.
@@ -30,6 +34,6 @@ class StringContentProvider(ContentProvider):
 
         """
         return [
-            AnalysisTarget(line, i + 1, self.lines, self.file_path, self.file_type, self.info)
-            for i, line in enumerate(self.lines)
+            AnalysisTarget(line, line_number, self.lines, self.file_path, self.file_type, self.info)
+            for line_number, line in zip(self.line_numbers, self.lines)
         ]
