@@ -1,5 +1,5 @@
 import logging
-from typing import Dict, List, Optional
+from typing import List, Optional
 
 from credsweeper.file_handler.analysis_target import AnalysisTarget
 from credsweeper.file_handler.content_provider import ContentProvider
@@ -16,8 +16,12 @@ class TextContentProvider(ContentProvider):
 
     """
 
-    def __init__(self, file_path: str, change_type: Optional[str] = None, diff: Optional[List[Dict]] = None) -> None:
-        super().__init__(file_path)
+    def __init__(
+            self,
+            file_path: str,  #
+            file_type: Optional[str] = None,  #
+            info: Optional[str] = None) -> None:
+        super().__init__(file_path=file_path, file_type=file_type, info=info)
 
     def get_analysis_target(self) -> List[AnalysisTarget]:
         """Load and preprocess file content to scan.
